<?php
/**
 * Moral Theme Customizer
 *
 * @package Moral
 *
 * featured_news section
 */

$wp_customize->add_section(
	'moral_magazine_pro_featured_news',
	array(
		'title' => esc_html__( 'Featured News', 'moral-magazine-pro' ),
		'panel' => 'moral_magazine_pro_home_panel',
	)
);

// featured_news enable settings
$wp_customize->add_setting(
	'moral_magazine_pro_featured_news',
	array(
		'sanitize_callback' => 'moral_magazine_pro_sanitize_select',
		'default' => 'cat'
	)
);

$wp_customize->add_control(
	'moral_magazine_pro_featured_news',
	array(
		'section'		=> 'moral_magazine_pro_featured_news',
		'label'			=> esc_html__( 'Content type:', 'moral-magazine-pro' ),
		'description'			=> esc_html__( 'Choose where you want to render the content from.', 'moral-magazine-pro' ),
		'type'			=> 'select',
		'choices'		=> array( 
				'disable' => esc_html__( '--Disable--', 'moral-magazine-pro' ),
				'post' => esc_html__( 'Post', 'moral-magazine-pro' ),
				'page' => esc_html__( 'Page', 'moral-magazine-pro' ),
				'cat' => esc_html__( 'Category', 'moral-magazine-pro' ),
		 	)
	)
);

$wp_customize->add_setting(
	'moral_magazine_pro_featured_news_col_layout',
	array(
		'sanitize_callback' => 'moral_magazine_pro_sanitize_select',
		'default' => 'col-2'
	)
);

$wp_customize->add_control(
	'moral_magazine_pro_featured_news_col_layout',
	array(
		'label'			=> esc_html__( 'Column Layout', 'moral-magazine-pro' ),
		'section'		=> 'moral_magazine_pro_featured_news',
		'type'			=> 'select',
		'choices'		=> array( 
				'col-1' => esc_html__( 'Column 1', 'moral-magazine-pro' ),
				'col-2' => esc_html__( 'Column 2', 'moral-magazine-pro' ),
		 	)
	)
);

$wp_customize->add_setting(
	'moral_magazine_pro_featured_news_title',
	array(
		'sanitize_callback' => 'sanitize_text_field',
		'default' => esc_html__( 'Featured News', 'moral-magazine-pro' ),
		'transport'	=> 'postMessage',
	)
);

$wp_customize->add_control(
	'moral_magazine_pro_featured_news_title',
	array(
		'section'		=> 'moral_magazine_pro_featured_news',
		'label'			=> esc_html__( 'Title:', 'moral-magazine-pro' ),
	)
);

$wp_customize->selective_refresh->add_partial( 
	'moral_magazine_pro_featured_news_title', 
	array(
        'selector'            => '#featured_news-posts .section-subtitle',
		'render_callback'     => 'moral_magazine_pro_featured_news_partial_title',
	) 
);

// featured_news number setting
$wp_customize->add_setting(
	'moral_magazine_pro_featured_news_num',
	array(
		'sanitize_callback' => 'moral_magazine_pro_sanitize_number_range',
		'default' => 4,
	)
);

$wp_customize->add_control(
	'moral_magazine_pro_featured_news_num',
	array(
		'section'		=> 'moral_magazine_pro_featured_news',
		'label'			=> esc_html__( 'Number of Posts:', 'moral-magazine-pro' ),
		'description'			=> esc_html__( 'Min: 3 | Max: 99', 'moral-magazine-pro' ),
		'type'			=> 'number',
		'input_attrs'	=> array( 'min' => 3, 'max' => 99 ),
	)
);

$featured_news_num = get_theme_mod( 'moral_magazine_pro_featured_news_num', 4 );
for ($i=1; $i <= $featured_news_num ; $i++) { 
	// featured_news post setting
	$wp_customize->add_setting(
		'moral_magazine_pro_featured_news_post_'.$i,
		array(
			'sanitize_callback' => 'moral_magazine_pro_sanitize_dropdown_pages',
		)
	);

	$wp_customize->add_control(
		'moral_magazine_pro_featured_news_post_'.$i,
		array(
			'section'		=> 'moral_magazine_pro_featured_news',
			'label'			=> esc_html__( 'Post ', 'moral-magazine-pro' ).$i,
			'active_callback' => 'moral_magazine_pro_if_featured_news_post',
			'type'			=> 'select',
			'choices'		=> moral_magazine_pro_get_post_choices(),
		)
	);

	// featured_news page setting
	$wp_customize->add_setting(
		'moral_magazine_pro_featured_news_page_'.$i,
		array(
			'sanitize_callback' => 'moral_magazine_pro_sanitize_dropdown_pages',
			'default' => 0,
		)
	);

	$wp_customize->add_control(
		'moral_magazine_pro_featured_news_page_'.$i,
		array(
			'section'		=> 'moral_magazine_pro_featured_news',
			'label'			=> esc_html__( 'Page ', 'moral-magazine-pro' ).$i,
			'type'			=> 'dropdown-pages',
			'active_callback' => 'moral_magazine_pro_if_featured_news_page'
		)
	);
}

// featured_news category setting
$wp_customize->add_setting(
	'moral_magazine_pro_featured_news_cat',
	array(
		'sanitize_callback' => 'moral_magazine_pro_sanitize_select',
	)
);

$wp_customize->add_control(
	'moral_magazine_pro_featured_news_cat',
	array(
		'section'		=> 'moral_magazine_pro_featured_news',
		'label'			=> esc_html__( 'Category:', 'moral-magazine-pro' ),
		'active_callback' => 'moral_magazine_pro_if_featured_news_cat',
		'type'			=> 'select',
		'choices'		=> moral_magazine_pro_get_post_cat_choices(),
	)
);

// // Style 

// // overlay enable settings
// $wp_customize->add_setting(
// 	'moral_magazine_pro_featured_news_overlay',
// 	array(
// 		'sanitize_callback' => 'moral_magazine_pro_sanitize_checkbox',
// 		'default' => false,
// 	)
// );

// $wp_customize->add_control(
// 	'moral_magazine_pro_featured_news_overlay',
// 	array(
// 		'section'		=> 'moral_magazine_pro_featured_news',
// 		'label'			=> esc_html__( 'Enable Overlay', 'moral-magazine-pro' ),
// 		'type'			=> 'checkbox',
// 	)
// );

// $wp_customize->add_setting(	
// 	'moral_magazine_pro_featured_news_section_sub_title_color',
// 	array(
// 		'sanitize_callback' => 'moral_magazine_pro_sanitize_hex_color',
// 	)
// );

// $wp_customize->add_control(
// 	new WP_Customize_Color_Control( 
// 	$wp_customize,
// 		'moral_magazine_pro_featured_news_section_sub_title_color',
// 		array(
// 			'section'		=> 'moral_magazine_pro_featured_news',
// 			'label'			=> esc_html__( 'Section Title Color', 'moral-magazine-pro' ),

// 		)
// 	)
// );


// $wp_customize->add_setting(	
// 	'moral_magazine_pro_featured_news_section_btn_color',
// 	array(
// 		'sanitize_callback' => 'moral_magazine_pro_sanitize_hex_color',
// 	)
// );


// $wp_customize->add_control(
// 	new WP_Customize_Color_Control( 
// 	$wp_customize,
// 		'moral_magazine_pro_featured_news_section_btn_color',
// 		array(
// 			'section'		=> 'moral_magazine_pro_featured_news',
// 			'label'			=> esc_html__( 'Section Btn Color', 'moral-magazine-pro' ),

// 		)
// 	)
// );

// $wp_customize->add_setting(	
// 	'moral_magazine_pro_featured_news_section_btn_text_color',
// 	array(
// 		'sanitize_callback' => 'moral_magazine_pro_sanitize_hex_color',
// 	)
// );


// $wp_customize->add_control(
// 	new WP_Customize_Color_Control( 
// 	$wp_customize,
// 		'moral_magazine_pro_featured_news_section_btn_text_color',
// 		array(
// 			'section'		=> 'moral_magazine_pro_featured_news',
// 			'label'			=> esc_html__( 'Section Btn Text Color', 'moral-magazine-pro' ),

// 		)
// 	)
// );


// $wp_customize->add_setting(	
// 	'moral_magazine_pro_featured_news_section_hover_btn_color',
// 	array(
// 		'sanitize_callback' => 'moral_magazine_pro_sanitize_hex_color',
// 	)
// );


// $wp_customize->add_control(
// 	new WP_Customize_Color_Control( 
// 	$wp_customize,
// 		'moral_magazine_pro_featured_news_section_hover_btn_color',
// 		array(
// 			'section'		=> 'moral_magazine_pro_featured_news',
// 			'label'			=> esc_html__( 'Section Btn Hover Color', 'moral-magazine-pro' ),

// 		)
// 	)
// );

// $wp_customize->add_setting(	
// 	'moral_magazine_pro_featured_news_section_hover_btn_text_color',
// 	array(
// 		'sanitize_callback' => 'moral_magazine_pro_sanitize_hex_color',
// 	)
// );


// $wp_customize->add_control(
// 	new WP_Customize_Color_Control( 
// 	$wp_customize,
// 		'moral_magazine_pro_featured_news_section_hover_btn_text_color',
// 		array(
// 			'section'		=> 'moral_magazine_pro_featured_news',
// 			'label'			=> esc_html__( 'Section Btn Text Hover Color', 'moral-magazine-pro' ),

// 		)
// 	)
// );


// // featured_news enable background settings
// $wp_customize->add_setting(
// 	'moral_magazine_pro_featured_news_background',
// 	array(
// 		'sanitize_callback' => 'moral_magazine_pro_sanitize_select',
// 	)
// );

// $wp_customize->add_control(
// 	'moral_magazine_pro_featured_news_background',
// 	array(
// 		'label'			=> esc_html__( 'Enable Background', 'moral-magazine-pro' ),
// 		'section'		=> 'moral_magazine_pro_featured_news',
// 		'type'			=> 'radio',
// 		'choices'		=> array( 
// 				'image' => esc_html__( 'Background Image', 'moral-magazine-pro' ),
// 				'color' => esc_html__( 'Background Color', 'moral-magazine-pro' ),
// 		 	),
// 	)
// );

// $wp_customize->add_setting( 'moral_magazine_pro_featured_news_background_image', array(
// 	'sanitize_callback' => 'moral_magazine_pro_sanitize_image',
// ) );

// $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'moral_magazine_pro_featured_news_background_image',
// 	array(
// 	'label'       		=> esc_html__( 'Upload Image', 'moral-magazine-pro' ),
// 	'section'     		=> 'moral_magazine_pro_featured_news',
// 	'active_callback'	=> 'moral_magazine_pro_if_featured_news_background_image',
// ) ) );

// $wp_customize->add_setting(	
// 	'moral_magazine_pro_featured_news_background_color',
// 	array(
// 		'sanitize_callback' => 'moral_magazine_pro_sanitize_hex_color',
// 	)
// );

// $wp_customize->add_control(
// 	new WP_Customize_Color_Control( 
// 	$wp_customize,
// 		'moral_magazine_pro_featured_news_background_color',
// 		array(
// 			'section'		=> 'moral_magazine_pro_featured_news',
// 			'label'			=> esc_html__( 'Select BG Color:', 'moral-magazine-pro' ),
// 			'active_callback' => 'moral_magazine_pro_if_featured_news_background_color',
// 		)
// 	)
// );
