<?php
/**
 * Moral Theme Customizer
 *
 * @package Moral
 *
 * travel_news section
 */

$wp_customize->add_section(
	'moral_magazine_pro_travel_news',
	array(
		'title' => esc_html__( 'Travel News', 'moral-magazine-pro' ),
		'panel' => 'moral_magazine_pro_home_panel',
	)
);

// travel_news enable settings
$wp_customize->add_setting(
	'moral_magazine_pro_travel_news',
	array(
		'sanitize_callback' => 'moral_magazine_pro_sanitize_select',
		'default' => 'cat'
	)
);

$wp_customize->add_control(
	'moral_magazine_pro_travel_news',
	array(
		'section'		=> 'moral_magazine_pro_travel_news',
		'label'			=> esc_html__( 'Content type:', 'moral-magazine-pro' ),
		'description'			=> esc_html__( 'Choose where you want to render the content from.', 'moral-magazine-pro' ),
		'type'			=> 'select',
		'choices'		=> array( 
				'disable' => esc_html__( '--Disable--', 'moral-magazine-pro' ),
				'post' => esc_html__( 'Post', 'moral-magazine-pro' ),
				'page' => esc_html__( 'Page', 'moral-magazine-pro' ),
				'cat' => esc_html__( 'Category', 'moral-magazine-pro' ),
		 	)
	)
);

$wp_customize->add_setting(
	'moral_magazine_pro_travel_news_title',
	array(
		'sanitize_callback' => 'sanitize_text_field',
		'default' => esc_html__( 'Travel News', 'moral-magazine-pro' ),
		'transport'	=> 'postMessage',
	)
);

$wp_customize->add_control(
	'moral_magazine_pro_travel_news_title',
	array(
		'section'		=> 'moral_magazine_pro_travel_news',
		'label'			=> esc_html__( 'Title:', 'moral-magazine-pro' ),
	)
);

$wp_customize->selective_refresh->add_partial( 
	'moral_magazine_pro_travel_news_title', 
	array(
        'selector'            => '#travel_news-posts .section-subtitle',
		'render_callback'     => 'moral_magazine_pro_travel_news_partial_title',
	) 
);

// travel_news number setting
$wp_customize->add_setting(
	'moral_magazine_pro_travel_news_num',
	array(
		'sanitize_callback' => 'moral_magazine_pro_sanitize_number_range',
		'default' => 4,
	)
);

$wp_customize->add_control(
	'moral_magazine_pro_travel_news_num',
	array(
		'section'		=> 'moral_magazine_pro_travel_news',
		'label'			=> esc_html__( 'Number of Posts:', 'moral-magazine-pro' ),
		'description'			=> esc_html__( 'Min: 3 | Max: 99', 'moral-magazine-pro' ),
		'type'			=> 'number',
		'input_attrs'	=> array( 'min' => 3, 'max' => 99 ),
	)
);

$travel_news_num = get_theme_mod( 'moral_magazine_pro_travel_news_num', 4 );
for ($i=1; $i <= $travel_news_num ; $i++) { 
	// travel_news post setting
	$wp_customize->add_setting(
		'moral_magazine_pro_travel_news_post_'.$i,
		array(
			'sanitize_callback' => 'moral_magazine_pro_sanitize_dropdown_pages',
		)
	);

	$wp_customize->add_control(
		'moral_magazine_pro_travel_news_post_'.$i,
		array(
			'section'		=> 'moral_magazine_pro_travel_news',
			'label'			=> esc_html__( 'Post ', 'moral-magazine-pro' ).$i,
			'active_callback' => 'moral_magazine_pro_if_travel_news_post',
			'type'			=> 'select',
			'choices'		=> moral_magazine_pro_get_post_choices(),
		)
	);

	// travel_news page setting
	$wp_customize->add_setting(
		'moral_magazine_pro_travel_news_page_'.$i,
		array(
			'sanitize_callback' => 'moral_magazine_pro_sanitize_dropdown_pages',
			'default' => 0,
		)
	);

	$wp_customize->add_control(
		'moral_magazine_pro_travel_news_page_'.$i,
		array(
			'section'		=> 'moral_magazine_pro_travel_news',
			'label'			=> esc_html__( 'Page ', 'moral-magazine-pro' ).$i,
			'type'			=> 'dropdown-pages',
			'active_callback' => 'moral_magazine_pro_if_travel_news_page'
		)
	);
}

// travel_news category setting
$wp_customize->add_setting(
	'moral_magazine_pro_travel_news_cat',
	array(
		'sanitize_callback' => 'moral_magazine_pro_sanitize_select',
	)
);

$wp_customize->add_control(
	'moral_magazine_pro_travel_news_cat',
	array(
		'section'		=> 'moral_magazine_pro_travel_news',
		'label'			=> esc_html__( 'Category:', 'moral-magazine-pro' ),
		'active_callback' => 'moral_magazine_pro_if_travel_news_cat',
		'type'			=> 'select',
		'choices'		=> moral_magazine_pro_get_post_cat_choices(),
	)
);

$wp_customize->add_setting( 'moral_magazine_pro_travel_news_ads_image', array(
	'sanitize_callback' => 'moral_magazine_pro_sanitize_image',
	'default'			=> get_template_directory_uri() . '/assets/img/site-advertisement.jpg',
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'moral_magazine_pro_travel_news_ads_image',
	array(
	'label'       		=> esc_html__( 'Ads Image', 'moral-magazine-pro' ),
	'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'moral-magazine-pro' ), 810, 120 ),
	'section'     		=> 'moral_magazine_pro_travel_news',
) ) );

// ads link setting and control
$wp_customize->add_setting( 'moral_magazine_pro_travel_news_ads_image_url', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'moral_magazine_pro_travel_news_ads_image_url', array(
	'label'           	=> esc_html__( 'Ads Url', 'moral-magazine-pro' ),
	'section'        	=> 'moral_magazine_pro_travel_news',
	'type'				=> 'url',
) );
